// *****************************************************************************
// File:			dgVoodooD3D11.hpp
//
// Description:		dgVoodoo - things related to the D3D11 backend
//
// Contact person:	DG
//
// *****************************************************************************

#ifndef DGVOODOOD3D11_HPP
#define DGVOODOOD3D11_HPP

#include "APITypes.h"

// --- Defines -----------------------------------------------------------------

// Vertex shaders

#define VS_SHADERTYPE_BASE				0x100

#define	SHADERTYPE_INTERNAL_VS_FF		(VS_SHADERTYPE_BASE+0)		// internal vertex shader used for untransformed, unlit vertices
#define	SHADERTYPE_INTERNAL_VS_FF_L		(VS_SHADERTYPE_BASE+1)		// internal vertex shader used for untransformed, lit vertices
#define	SHADERTYPE_INTERNAL_VS_FF_TL	(VS_SHADERTYPE_BASE+2)		// internal vertex shader used for transformed-lit (TL) vertices

#define	SHADERTYPE_EXTERNAL_VS			(VS_SHADERTYPE_BASE+3)		// external vertex shader created by the application

// Pixel shaders

#define PS_SHADERTYPE_BASE				0x200

#define SHADERTYPE_INTERNAL_PS_FF_V0	(PS_SHADERTYPE_BASE+0)		// internal pixel shader used for ff pipeline (level0)
#define SHADERTYPE_INTERNAL_PS_FF_V1	(PS_SHADERTYPE_BASE+1)		// internal pixel shader used for ff pipeline (level1)
#define SHADERTYPE_INTERNAL_PS_FF_V2	(PS_SHADERTYPE_BASE+2)		// internal pixel shader used for ff pipeline (level2)
#define SHADERTYPE_INTERNAL_PS_FF_V3	(PS_SHADERTYPE_BASE+3)		// internal pixel shader used for ff pipeline (level3)

#define SHADERTYPE_EXTERNAL_PS_FF		(PS_SHADERTYPE_BASE+4)		// external pixel shader built from a configuration of the FF pixel pipeline
#define SHADERTYPE_EXTERNAL_PS_PS		(PS_SHADERTYPE_BASE+5)		// external pixel shader created by bytecode coming from the application


// --- GUID definitions --------------------------------------------------------

// {F934D3AC-BFE8-4354-9AF7-39F6F502333E}
DEFINE_GUID (IID_DGVD3D11_VSShaderInfo, 0xf934d3ac, 0xbfe8, 0x4354, 0x9a, 0xf7, 0x39, 0xf6, 0xf5, 0x2, 0x33, 0x3e);

// {4E89E86B-B9B0-49A1-9FFA-53A72498CD2B}
DEFINE_GUID (IID_DGVD3D11_PSShaderInfo, 0x4e89e86b, 0xb9b0, 0x49a1, 0x9f, 0xfa, 0x53, 0xa7, 0x24, 0x98, 0xcd, 0x2b);


namespace dgVoodoo {

// --- Vertex shader info

struct D3D11VertexShaderInfo
{
	const DWORD*	pSrcCode;					// NULL for internal shaders
												// Points to the source from which this variant is built for external shaders
	UInt32			shaderType;
};


// --- Pixel shader info

struct D3D11PixelShaderInfo
{
	const DWORD*	pSrcCode;					// NULL for internal shaders
												// Points to the source from which this variant is built for external shaders
	UInt32			shaderType;
};


}	// namespace dgVoodoo


#endif	// DGVOODOOD3D11_HPP